#[cfg(feature = "rapidoc")]
pub(crate) mod rapidoc;
#[cfg(feature = "redoc")]
pub(crate) mod redoc;
#[cfg(feature = "swagger-ui")]
pub(crate) mod swagger_ui;
